oslo.config
===========

An OpenStack library for parsing configuration options from the command
line and configuration files.

Contents
========

.. toctree::
   :maxdepth: 2

   cfg
   opts
   types
   configopts
   cfgfilter
   helpers
   fixture
   parser
   exceptions
   namespaces
   styleguide
   mutable
   generator
   builtins
   sphinxext
   sphinxconfiggen
   faq
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

